Function pgx_pg_sys::heap_tuple_get_struct
source · Expand description
Retrieve the “user data” of the specified [HeapTuple] as a specific type. Typically this
will be a struct that represents a Postgres system catalog, such as [FormData_pg_class].
Returns
A pointer to the [HeapTuple]’s “user data”, cast as a mutable pointer to T. If the
specified htup pointer is null, the null pointer is returned.
Safety
This function cannot verify that the specified htup points to a valid [HeapTuple] nor
that if it does, that its bytes are bitwise compatible with T.