#[repr(C)]
pub struct FormData_pg_proc {Show 20 fields
pub oid: Oid,
pub proname: NameData,
pub pronamespace: Oid,
pub proowner: Oid,
pub prolang: Oid,
pub procost: float4,
pub prorows: float4,
pub provariadic: Oid,
pub prosupport: regproc,
pub prokind: c_char,
pub prosecdef: bool,
pub proleakproof: bool,
pub proisstrict: bool,
pub proretset: bool,
pub provolatile: c_char,
pub proparallel: c_char,
pub pronargs: int16,
pub pronargdefaults: int16,
pub prorettype: Oid,
pub proargtypes: oidvector,
}
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.