Struct pgx_pg_sys::TypeName

source ·
#[repr(C)]
pub struct TypeName { pub type_: NodeTag, pub names: *mut List, pub typeOid: Oid, pub setof: bool, pub pct_type: bool, pub typmods: *mut List, pub typemod: int32, pub arrayBounds: *mut List, pub location: c_int, }
Supporting data structures for Parse Trees

Most of these node types appear in raw parsetrees output by the grammar, and get transformed to something else by the analyzer. A few of them are used as-is in transformed querytrees.

Fields

type_: NodeTagnames: *mut ListtypeOid: Oidsetof: boolpct_type: booltypmods: *mut Listtypemod: int32arrayBounds: *mut Listlocation: c_int