pub struct PgTryResult<T>(_);
A std::result::Result-type value returned from pg_try() that allows for performing cleanup work after a closure raised an error and before it is possibly rethrown

Implementations

Retrieve the returned value or panic if the try block raised an error

Safety

This function is unsafe because you might be ignoring a caught Postgres ERROR (or Rust panic) and you better know what you’re doing when you do that.

Doing so can potentially leave Postgres in an undefined state and ultimately cause it to crash.

Perform some operation cleanup operation after the try block if an error was thrown.

Safety

This function does not rethrow a caught ERROR. You better know what you’re doing when you call this function.

Ignoring a caught error can leave Postgres in an undefined state and ultimately cause it to crash.

Perform some operation cleanup operation after the try block if an error was thrown.

In the event an error was caught, it is rethrown.

Perform some operation after the try block completes, regardless of if an error was thrown.

In the event an error was caught, it is rethrown. Otherwise, the return value from the try block is returned