pub unsafe fn HeapTupleHeaderGetNatts(tup: *const HeapTupleHeaderData) -> u16Expand description
How many attributes does the specified [HeapTupleHeader] have?
Safety
Caller is responsible for ensuring tup is a valid pointer
pub unsafe fn HeapTupleHeaderGetNatts(tup: *const HeapTupleHeaderData) -> u16How many attributes does the specified [HeapTupleHeader] have?
Caller is responsible for ensuring tup is a valid pointer