pub unsafe fn HeapTupleNoNulls(tup: *const HeapTupleData) -> boolExpand description
Does the specified [HeapTuple] (tup) contain nulls?
Safety
Caller is responsible for ensuring tup is a valid pointer
pub unsafe fn HeapTupleNoNulls(tup: *const HeapTupleData) -> boolDoes the specified [HeapTuple] (tup) contain nulls?
Caller is responsible for ensuring tup is a valid pointer