pub struct ErrorReportWithLevel { /* private fields */ }

Implementations

Returns the logging level of this error report

Returns the sql error code of this error report

Returns the error message of this error report

Returns the detail line of this error report, if there is one

Returns the hint line of this error report, if there is one

Returns the name of the source file that generated this error report

Returns the line number of the source file that generated this error report

Returns the name of the function that generated this error report, if we were able to figure it out