pub trait ErrorReportable {
    type Inner;

    fn report(self) -> Self::Inner;
}
Indicates that something can be reported as a Postgres ERROR, if that’s what it might represent.

Required Associated Types

Required Methods

Raise a Postgres ERROR if appropriate, otherwise return a value

Implementations on Foreign Types

If this Result represents the Ok variant, that value is returned.

If this Result represents the Err variant, raise it as an error. If it happens to be an ErrorReport, then that is specifically raised. Otherwise it’s just a general ereport! as a PgLogLevel::ERROR.

Implementors