Struct pgx_pg_sys::submodules::NullableDatum
source · [−]Expand description
This struct consists of a Datum and a bool, matching Postgres’s definition as of Postgres 12. This isn’t efficient in terms of storage size, due to padding, but sometimes it’s more cache-friendly, so sometimes it is the preferred type.
Fields
value: Datumisnull: boolTrait Implementations
sourceimpl Clone for NullableDatum
impl Clone for NullableDatum
sourcefn clone(&self) -> NullableDatum
fn clone(&self) -> NullableDatum
Returns a copy of the value. Read more
1.0.0 · sourceconst fn clone_from(&mut self, source: &Self)
const fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for NullableDatum
impl Debug for NullableDatum
sourceimpl From<NullableDatum> for Option<Datum>
impl From<NullableDatum> for Option<Datum>
sourcefn from(nd: NullableDatum) -> Option<Datum>
fn from(nd: NullableDatum) -> Option<Datum>
Converts to this type from the input type.
sourceimpl TryFrom<NullableDatum> for Datum
impl TryFrom<NullableDatum> for Datum
impl Copy for NullableDatum