Module pgx_pg_sys::submodules::panic
source · Structs
Represents the set of information necessary for pgx to promote a Rust
panic!() to a Postgres
ERROR (or any PgLogLevel level)Enums
What kind of error was caught?
Traits
Indicates that something can be reported as a Postgres ERROR, if that’s what it might represent.