Struct pgx_pg_sys::submodules::panic::ErrorReportWithLevel
source · pub struct ErrorReportWithLevel { /* private fields */ }Implementations
sourceimpl ErrorReportWithLevel
impl ErrorReportWithLevel
sourcepub fn level(&self) -> PgLogLevel
pub fn level(&self) -> PgLogLevel
Returns the logging level of this error report
sourcepub fn sql_error_code(&self) -> PgSqlErrorCode
pub fn sql_error_code(&self) -> PgSqlErrorCode
Returns the sql error code of this error report
sourcepub fn detail(&self) -> Option<&str>
pub fn detail(&self) -> Option<&str>
Returns the detail line of this error report, if there is one
sourcepub fn file(&self) -> &str
pub fn file(&self) -> &str
Returns the name of the source file that generated this error report
sourcepub fn line_number(&self) -> u32
pub fn line_number(&self) -> u32
Returns the line number of the source file that generated this error report
sourcepub fn function_name(&self) -> Option<&str>
pub fn function_name(&self) -> Option<&str>
Returns the name of the function that generated this error report, if we were able to figure it out